Syncing charts

<div id="wrapper"> <div id="chart-line"> <ReactApexChart options={this.state.options} series={this.state.series} type="line" height={160} /> </div> <div id="chart-line2"> <ReactApexChart options={this.state.optionsLine2} series={this.state.seriesLine2} type="line" height={160} /> </div> <div id="chart-area"> <ReactApexChart options={this.state.optionsArea} series={this.state.seriesArea} type="area" height={160} /> </div> <div class="columns"> <div id="chart-small"> <ReactApexChart options={this.state.optionsSmall} series={this.state.seriesSmall} type="area" height={160} width={300} /> </div> <div id="chart-small2"> <ReactApexChart options={this.state.optionsSmall2} series={this.state.seriesSmall2} type="area" height={160} width={300} /> </div> </div> </div>